@@ -225,7 +225,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
     Saves Model at each end of the epoch when the best accuracy/loss is presented.
     """
     def __init__(self, best_metric=float('inf'), save_root="./", save_metric='val_loss',
-                metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False):
+                metric_type="loss",file_name="my_model", enable=True, epoch=0, include_optimizer=False, save_func=None):
         """
 
         Args:
@@ -235,6 +235,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
             enable (bool): Set previous epoch number if resuming
             epoch (int): Epoch number
             metric_type (str): (loss, score)
+            save_func (function, None): If given, it overrides model save function. Ex) save_func("save_path.h5", include_optimizer=include_optimizer)
         """
         super(ModelSaverCallback, self).__init__()
         self.best_metric = best_metric
@@ -248,6 +249,7 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
         self.file_name = file_name
         self.include_optimizer = include_optimizer
         self.metric_type = metric_type
+        self.save_func = save_func
 
     def on_epoch_end(self, epoch, logs=None):
         try:
@@ -277,7 +279,10 @@ class ModelSaverCallback(tf.keras.callbacks.Callback):
                 self.best_metric = logs[self.save_metric]
 
                 if self.enable:
-                    self.model.save(file_name, include_optimizer=self.include_optimizer)
+                    if self.save_func:
+                        self.save_func(file_name, include_optimizer=self.include_optimizer)
+                    else:
+                        self.model.save(file_name, include_optimizer=self.include_optimizer)
         except Exception as e:
             print(e)
 
@@ -419,7 +424,8 @@ def wait_ctrl_c(pre_msg="Press Ctrl+c to quit Tensorboard", post_msg="\nExit."):
 def get_tf_callbacks(root,
                      tboard_callback=True, tboard_update_freq='epoch', tboard_histogram_freq=1, tboard_profile_batch=0,
                      confuse_callback=True, label_info=None, x_test=None, y_test=None, test_generator_=None, test_dataset=None, figure_size=(12, 10), model_out_idx=-1,
-                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0, save_metric='val_loss', save_file_name="my_model", metric_type="loss",
+                     modelsaver_callback=False, best_loss=float('inf'), save_root=None, best_epoch=0,
+                     save_metric='val_loss', save_file_name="my_model", metric_type="loss", save_func=None,
                      earlystop_callback=True, earlystop_monitor='val_loss', earlystop_patience=0, earlystop_restore_weights=True,
                      sparsity_callback=False, sparsity_threshold=0.05):
     """
@@ -495,7 +501,7 @@ def get_tf_callbacks(root,
             save_root = log_root_
         callbacks_.append(
             ModelSaverCallback(best_metric=best_loss, save_root=save_root, epoch=best_epoch, save_metric=save_metric,
-                               file_name=save_file_name, metric_type=metric_type)
+                               file_name=save_file_name, metric_type=metric_type, save_func=save_func)
         )
 
     if earlystop_callback:
